@@ -1,12 +1,69 @@
+from abc import ABC, abstractmethod
 import datetime as dt
 import numpy as np
 import bokeh.models
-from forest import geo
+import forest.data
+from forest import geo, colors
 from forest.old_state import old_state, unique
 from forest.exceptions import FileNotFound, IndexNotFound
 
 
-class UMView(object):
+def map_view(loader, color_mapper, use_hover_tool=True):
+    """Convenient method to simplify MapView construction"""
+    if forest.data.FEATURE_FLAGS["multiple_colorbars"]:
+        color_mapper = bokeh.models.LinearColorMapper(
+            palette="Greys256",
+            low=0,
+            high=1)
+        color_view = ColorView(color_mapper)
+        um_view = UMView(loader, color_mapper,
+                         use_hover_tool=use_hover_tool)
+        return MapView(um_view, color_view)
+    else:
+        return UMView(loader, color_mapper,
+                      use_hover_tool=use_hover_tool)
+
+
+class AbstractMapView(ABC):
+    @abstractmethod
+    def add_figure(self, figure):
+        pass
+
+    @abstractmethod
+    def render(self, state):
+        pass
+
+
+class MapView(AbstractMapView):
+    """Extend UMView to support color_mapper"""
+    def __init__(self, um_view, color_view):
+        self.um_view = um_view
+        self.color_view = color_view
+
+    @property
+    def image_sources(self):
+        return self.um_view.image_sources
+
+    def add_figure(self, figure):
+        return self.um_view.add_figure(figure)
+
+    def render(self, state):
+        self.color_view.render(state)
+        self.um_view.render(state)
+
+
+class ColorView:
+    """Applies ColorSpec to bokeh.models.LinearColorMapper"""
+    def __init__(self, color_mapper):
+        self.color_mapper = color_mapper
+
+    def render(self, state):
+        if "colorbar" in state:
+            spec = colors.parse_color_spec(state["colorbar"])
+            spec.apply(self.color_mapper)
+
+
+class UMView(AbstractMapView):
     def __init__(self, loader, color_mapper, use_hover_tool=True):
         self.loader = loader
         self.color_mapper = color_mapper
@@ -29,8 +86,8 @@ class UMView(object):
             ("Level", "@level")]
 
         self.formatters = {
-            'valid': 'datetime',
-            'initial': 'datetime'
+            '@valid': 'datetime',
+            '@initial': 'datetime'
         }
 
     @old_state
